==> contentsquare-1.0.1.tar.gz: example/simple_app/lib/src/screens/info/info_screen.dart <==
import 'dart:convert';

import 'package:flutter/material.dart';

import '../../widgets/contentsquare_progress_indicator.dart';

class InfoScreen extends StatelessWidget {
  const InfoScreen({Key? key}) : super(key: key);

  @override
  Widget build(BuildContext context) {
    return Center(
      child: FutureBuilder<String>(
        future: DefaultAssetBundle.of(context)
            .loadString('assets/versions_info.json'),
        builder: (context, snapshot) {
          if (!snapshot.hasData) {
            return ContentsquareProgressIndicator();
          }

          final versionsInfo = json.decode(snapshot.data.toString());

          return Column(
            mainAxisSize: MainAxisSize.min,
            children: [
              Text(
                'SDK Versions',
                style: Theme.of(context).textTheme.headline6,
              ),
              SizedBox(height: 30),
              Text('iOS SDK Version: ${versionsInfo['iOSSDKVersion']}'),
              SizedBox(height: 15),
              Text('Android SDK Version: ${versionsInfo['androidSDKVersion']}'),
              SizedBox(height: 15),
              Text(
                  'Flutter SDK Version: ${versionsInfo['flutterPluginVersion']}'),
              SizedBox(height: 15),
              Text('Flutter Version: ${versionsInfo['flutterVersion']}'),
              SizedBox(height: 15),
              Text('Git Branch: ${versionsInfo['gitBranch']}'),
            ],
          );
        },
      ),
    );
  }
}

==> contentsquare-2.1.0.tar.gz: example/simple_app/lib/src/screens/info/info_screen.dart <==
import 'dart:convert';

import 'package:flutter/material.dart';

import '../../widgets/contentsquare_progress_indicator.dart';

class InfoScreen extends StatelessWidget {
  const InfoScreen({Key? key}) : super(key: key);

  @override
  Widget build(BuildContext context) {
    return Center(
      child: FutureBuilder<String>(
        future: DefaultAssetBundle.of(context)
            .loadString('assets/versions_info.json'),
        builder: (context, snapshot) {
          if (!snapshot.hasData) {
            return ContentsquareProgressIndicator();
          }

          final versionsInfo = json.decode(snapshot.data.toString());

          return Column(
            mainAxisSize: MainAxisSize.min,
            children: [
              Text(
                'SDK Versions',
                style: Theme.of(context).textTheme.titleLarge,
              ),
              SizedBox(height: 30),
              Text('iOS SDK Version: ${versionsInfo['iOSSDKVersion']}'),
              SizedBox(height: 15),
              Text('Android SDK Version: ${versionsInfo['androidSDKVersion']}'),
              SizedBox(height: 15),
              Text(
                  'Flutter SDK Version: ${versionsInfo['flutterPluginVersion']}'),
              SizedBox(height: 15),
              Text('Flutter Version: ${versionsInfo['flutterVersion']}'),
              SizedBox(height: 15),
              Text('Git Branch: ${versionsInfo['gitBranch']}'),
            ],
          );
        },
      ),
    );
  }
}
